#
# spec file for package zram-generator
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _systemd_util_dir /usr/lib/systemd

Name:           zram-generator
Version:        1.1.2
Release:        2.5
Summary:        Systemd unit generator for zram swap devices
License:        MIT
Group:          Development/Libraries/Rust

# Upstream license specification: MIT
URL:            https://github.com/systemd/zram-generator
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
Source3:        zram-generator-rpmlintrc

# pregenerated man-pages to avoid dependency on ronn
Source4:        zram-generator.conf.5
Source5:        zram-generator.8

BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(systemd)

%description
This is a systemd unit generator that enables swap on zram.
(With zram, there is no physical swap device. Part of the avaialable RAM
is used to store compressed pages, essentially trading CPU cycles for memory.)

To configure and activate swap and zram devices with file-systems,  create a configuration file in /etc/systemd/zram-generator.conf. You can consult  %{_datadir}/doc/%{name}/zram-generator.conf.example for an example and a list of available settings.

%prep
%autosetup -a1 -p1 -n %{name}-%{version}
mkdir .cargo
cp %{SOURCE2} .cargo/config
cp %{SOURCE4} man/
cp %{SOURCE5} man/

%build
export SYSTEMD_UTIL_DIR=%{_systemd_util_dir}
export LC_ALL=C.UTF-8
%{cargo_build}

%make_build SYSTEMD_SYSTEM_UNIT_DIR=%{_unitdir} SYSTEMD_SYSTEM_GENERATOR_DIR=%{_systemdgeneratordir} \
  systemd-service

%install
%make_install SYSTEMD_SYSTEM_UNIT_DIR=%{_unitdir} SYSTEMD_SYSTEM_GENERATOR_DIR=%{_systemdgeneratordir} NOBUILD=1

%check
export SYSTEMD_UTIL_DIR=%{_systemd_util_dir}
%{cargo_test}

%files
%doc README.md
%dir %{_datadir}/doc/%{name}
%{_datadir}/doc/%{name}/zram-generator.conf.example
%dir %{_systemdgeneratordir}
%{_systemdgeneratordir}/zram-generator
%{_unitdir}/systemd-zram-setup@.service
%{_mandir}/man8/zram-generator.8*
%{_mandir}/man5/zram-generator.conf.5*

%changelog
* Wed Jun 29 2022 Benjamin Brunner <bbrunner@suse.com>
- Fixed typo in description (bsc#1200961)
- Updated vendor.tar.xz
* Mon May  2 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.1.2:
  * Stable release version
- Updated vendor.tar.xz
* Wed Mar  2 2022 bbrunner@suse.com
- Update to version 1.1.1~git6.6923dc2:
  * Suggest /var/compressed instead of /var/tmp in README
  * Update install from source instruction
- Updated vendor.tar.xz
* Fri Jan  7 2022 William Brown <william.brown@suse.com>
  Updated vendor.tar.xz to
- not create uninitialized values in smallvec-crate
  (bsc#1194113, CVE-2018-25023)
- fix a possible data race and memory corruption when using a closed
  `oneshot` channel in tokio-crate (bsc#1194119, CVE-2021-45710)
* Fri Jan  7 2022 bbrunner@suse.com
- Update to version 1.1.1~git5.8612dbb:
  * Update install from source instruction
  * Document workaround for making zram mounts user-writable (c.f. #146)
  * Issue warning if /s/b/z0/backing_dev doesn't exist and wb-dev= set
  * Skip test if unshare fails
  * Accept NOMAN in Makefile, disabling build: and install: manpage processing
  * Version 1.1.1
  * Bump minimum rust-ini to 0.15, first one with ordered keys
  * Don't CLONE_NEWUSER when already root. Privatise all mounts first
  * Add Aqs around README mails
  * Update my author mail
* Fri Nov 26 2021 Benjamin Brunner <bbrunner@suse.com>
- Temporary pre-generate man-pages, to avoid dependency on
  rubygem-ronn, which is no longer maintained
* Thu Nov 11 2021 Benjamin Brunner <bbrunner@suse.com> 
- Update to version 1.0.1~git25.5e0ec60:
  * make: add BUILDTYPE switch
  * make: add "clippy" target
  * Use ?= instead of = for Makefile defaults
  * Do not warn on deprecated options
  * Fix the reference to the directory/device option name
  * Fix clippy
  * Fix clippy job
  * Warn on deprecated memory-limit
  * Remove deprecated values from test data, move their tests to 11-obsolete
  * Obsolete zram-fraction and max-zram-size in favour of new, arbitrary-expression, zram-size
* Wed Nov  3 2021 Benjamin Brunner <bbrunner@suse.com>
- Initial package for zram-generator (jsc#SLE-18818)
